@@ -417,7 +417,13 @@ send_to_pilot_cb(GtkButton* button,gpointer whatever)
 		user.userID = tmpPilot->pilot_id;
 		user.username = tmpPilot->pilot_username;
 
-		if(gnome_pilot_client_set_user_info(gpc,dev->name,user,GNOME_Pilot_IMMEDIATE,0,&handle)==GPILOTD_OK) {
+		if(gnome_pilot_client_set_user_info(gpc,
+						    dev->name,
+						    user,
+						    FALSE,
+						    GNOME_Pilot_IMMEDIATE,
+						    0,
+						    &handle)==GPILOTD_OK) {
 			run_sync_dialog(dev,handle);
 		} else {
 			run_error_dialog(_("The request to set pilot id failed"));
@@ -1191,6 +1197,7 @@ pilot_capplet_setup(void)
 
 				 
 	deviceCfgWindow = glade_xml_get_widget(xml,"devices_clist");
+	gtk_object_set_data(GTK_OBJECT(deviceCfgWindow),"selected",GINT_TO_POINTER(-1));
 	gtk_signal_connect(GTK_OBJECT(deviceCfgWindow), "select-row",
 			   GTK_SIGNAL_FUNC(devices_selection_cb), NULL);
 	gtk_signal_connect(GTK_OBJECT(deviceCfgWindow), "button_press_event",
@@ -1205,6 +1212,7 @@ pilot_capplet_setup(void)
 			   GTK_SIGNAL_FUNC(devices_delete_cb), deviceCfgWindow);
 	
 	pilotCfgWindow = glade_xml_get_widget(xml,"pilots_clist");
+	gtk_object_set_data(GTK_OBJECT(pilotCfgWindow),"selected",GINT_TO_POINTER(-1));
 	gtk_signal_connect(GTK_OBJECT(pilotCfgWindow), "select-row",
 			   GTK_SIGNAL_FUNC(pilots_selection_cb), NULL);
 	gtk_signal_connect(GTK_OBJECT(pilotCfgWindow), "button_press_event",
@@ -1485,7 +1493,13 @@ druid_presync_page_next(GnomeDruidPage *druidpage,GnomeDruid *druid,
 
 		user.userID = pilot->pilot_id;
 		user.username = pilot->pilot_username;
-		gnome_pilot_client_set_user_info(gpc,device->name,user,GNOME_Pilot_IMMEDIATE,0,&handle);
+		gnome_pilot_client_set_user_info(gpc,
+						 device->name,
+						 user,
+						 FALSE,
+						 GNOME_Pilot_IMMEDIATE,
+						 0,
+						 &handle);
 	} else {
 		/* do get_from_pilot */
 		text=g_strdup_printf(_("About to retrieve UserName and ID from the pilot.\n"
