@@ -16,10 +16,9 @@
 #include <config.h>
 #include <capplet-widget.h>
 
-#include <gpilotd/gpilotd-conduit-mgmt.h>
-#include <gpilotd/gpilotd-app.h>
-#include <gpilotd/gpilotd-app-dummy-callbacks.h>
-
+#include <gpilotd/gnome-pilot-client.h>
+#include <libgpilotdCM/gnome-pilot-conduit-management.h>
+#include <libgpilotdCM/gnome-pilot-conduit-config.h>
 #include "backup_conduit.h"
 
 /* tell changes callbacks to ignore changes or not */
@@ -34,7 +33,8 @@ GtkWidget *cfgStateWindow = NULL;
 GtkWidget *dialogWindow = NULL;
 
 gboolean activated,org_activation_state;
-GnomePilotConduitMgmt *conduit;
+GnomePilotConduitManagement *conduit;
+GnomePilotConduitConfig *conduit_config;
 
 ConduitCfg *origState = NULL;
 ConduitCfg *curState = NULL;
@@ -51,16 +51,146 @@ static void readStateCfg(GtkWidget *w, ConduitCfg *state,gboolean *);
 static void setStateCfg(GtkWidget *w, ConduitCfg *state,gboolean);
 
 gint pilotId;
+static GnomePilotClient *gpc;
 
 CORBA_Environment ev;
 
+static void 
+load_configuration(ConduitCfg **c,guint32 pilotId) 
+{
+	gchar *prefix;
+	gchar *exclude;
+	gchar **excs;
+	guint i;
+
+	*c = g_new0(ConduitCfg,1);
+	(*c)->child = -1;
+	
+	prefix = g_strdup_printf("/gnome-pilot.d/backup-conduit/Pilot_%u/",pilotId);
+	
+	gnome_config_push_prefix(prefix);
+	(*c)->backup_dir = gnome_config_get_string("backup_dir");
+	(*c)->updated_only = gnome_config_get_bool("updated_only=TRUE");
+	(*c)->remove_deleted = gnome_config_get_bool("remove_deleted=FALSE");	
+	exclude = gnome_config_get_string("exclude_files");
+	if(exclude != NULL) {
+	  (*c)->exclude_files = NULL;
+	  excs = g_strsplit( exclude, ",", 0 );
+	  for( i = 0; excs[i] != NULL ; i++ ) {
+	    (*c)->exclude_files = g_list_insert_sorted( (*c)->exclude_files , 
+							g_strdup(excs[i]),
+							(GCompareFunc)g_strcasecmp);
+	  }
+	  g_strfreev(excs);
+	}
+	gnome_config_pop_prefix();
+	
+	(*c)->files_in_backup = NULL;
+
+	if ((*c)->backup_dir == NULL) {
+		gchar *tmp;
+		gnome_pilot_client_get_pilot_base_dir_by_id(gpc,pilotId,&tmp);
+		(*c)->backup_dir = g_strdup_printf("%s/backup/",tmp);
+		g_free(tmp);
+	}
+	
+	if(mkdir((*c)->backup_dir,(mode_t)0755) < 0) { /* Wow, I never though I would
+							  use octal in C :) */
+		if(errno != EEXIST) {
+			/* YECH! 
+			   CONDUIT_CFG(c.gpilotd_methods)->log_error("Cannot open whatever...");
+			*/
+		}
+	}    
+	(*c)->pilotId = pilotId;
+	g_free(prefix);
+}
+
+static void 
+save_configuration(ConduitCfg *c) 
+{
+	gchar *prefix;
+	gchar **exclude;
+	gchar *exc=NULL;
+	GList *iterator;
+	guint i;
+
+	g_return_if_fail(c!=NULL);
+       	
+	prefix= g_strdup_printf("/gnome-pilot.d/backup-conduit/Pilot_%u/",c->pilotId);
+	
+	if( c->exclude_files != NULL ) {
+	  iterator = c->exclude_files;
+	  exclude = g_malloc( sizeof(char *) * (g_list_length(iterator)+1) );
+	  for( i=0 ; iterator != NULL ; iterator = iterator->next, i++ ) {
+	    exclude[i] = iterator->data;
+	  }
+	  exclude[i] = NULL;
+	  exc = g_strjoinv( ",", exclude);
+	  g_free(exclude);
+	}
+	gnome_config_push_prefix(prefix);
+	gnome_config_set_string("backup_dir",c->backup_dir);
+	gnome_config_set_bool("updated_only",c->updated_only);
+	gnome_config_set_bool("remove_deleted",c->remove_deleted);
+	gnome_config_set_string("exclude_files",exc);
+	gnome_config_pop_prefix();
+	gnome_config_sync();
+	gnome_config_drop_all();
+	g_free(prefix);
+	g_free(exc);
+}
+static void 
+copy_configuration(ConduitCfg *d, ConduitCfg *c)
+{
+        g_return_if_fail(c!=NULL);
+        g_return_if_fail(d!=NULL);
+	if(d->backup_dir) g_free(d->backup_dir);
+	d->backup_dir = g_strdup(c->backup_dir);
+	d->remove_deleted = c->remove_deleted;
+	d->updated_only = c->updated_only;
+	d->pilotId = c->pilotId;
+	d->child = c->child;
+	if(d->exclude_files) g_list_free(d->exclude_files);
+	d->exclude_files = g_list_copy(c->exclude_files);
+	if(d->files_in_backup) g_list_free(d->files_in_backup);
+	d->files_in_backup = g_list_copy(c->files_in_backup);
+}
+
+static ConduitCfg*
+dupe_configuration(ConduitCfg *c) 
+{
+	ConduitCfg *d;
+	g_return_val_if_fail(c!=NULL,NULL);
+	d = g_new0(ConduitCfg,1);
+	copy_configuration(d,c);
+	return d;
+}
+
+/** this method frees all data from the conduit config */
+static void 
+destroy_configuration(ConduitCfg **c) 
+{
+	g_return_if_fail(c!=NULL);
+	g_return_if_fail(*c!=NULL);
+
+	if((*c)->remove_deleted) {
+		g_list_free((*c)->files_in_backup);
+	}
+	
+	g_list_free((*c)->exclude_files);
+	g_free((*c)->backup_dir);
+	g_free(*c);
+	*c = NULL;
+}
+
 static void 
 setSettings(ConduitCfg* conduitCfg, gboolean active)
 {
     if(active)
-      gpilotd_conduit_mgmt_enable(conduit,pilotId,GnomePilotConduitSyncTypeCustom);
+      gnome_pilot_conduit_config_enable(conduit_config,GnomePilotConduitSyncTypeCustom);
     else
-      gpilotd_conduit_mgmt_disable(conduit,pilotId);
+      gnome_pilot_conduit_config_disable(conduit_config);
 
     save_configuration(conduitCfg);
 }
@@ -127,14 +257,7 @@ statechange_cb(GtkEditable    *editable, const gchar    *text,
 		capplet_widget_state_changed(CAPPLET_WIDGET(capplet), TRUE);
 }
 
-static void
-clist_changed(GtkWidget *widget, gpointer data)
-{
-	if (!ignore_changes)
-		capplet_widget_state_changed(CAPPLET_WIDGET(capplet), TRUE);
-}
-	
-void about_cb (GtkWidget *widget, gpointer data) {
+static void about_cb (GtkWidget *widget, gpointer data) {
 	GtkWidget *about;
 	const gchar *authors[] = {_("Eskil Heyn Olsen <deity@eskil.dk>"),NULL};
   
@@ -356,7 +479,7 @@ pilot_capplet_setup(void)
 	gtk_widget_show_all(capplet);
 }
 
-void run_error_dialog(gchar *mesg,...) {
+static void run_error_dialog(gchar *mesg,...) {
 	char tmp[80];
 	va_list ap;
 
@@ -367,70 +490,90 @@ void run_error_dialog(gchar *mesg,...) {
 	va_end(ap);
 }
 
-gint get_pilot_id_from_gpilotd() {
-	gint *pilots;
-	int i;
+static gint 
+get_pilot_id_from_gpilotd() 
+{
+	GList *pilots=NULL;
+	gint pilot;
+	int i,err;
   
 	i=0;
-	gpilotd_get_pilot_ids(&pilots);
-	if(pilots) {
-		while(pilots[i]!=-1) { g_message("pilot %d = \"%d\"",i,pilots[i]); i++; }
-		if(i==0) {
+	/* we don't worry about leaking here, so pilots isn't freed */
+	switch(err = gnome_pilot_client_get_pilots(gpc,&pilots)) {
+	case GPILOTD_OK: {
+		if(pilots) {
+			for(i=0;i<g_list_length(pilots);i++) {
+				g_message("pilot %d = \"%s\"",i,(gchar*)g_list_nth(pilots,i)->data); 
+			}
+			if(i==0) {
+				run_error_dialog(_("No pilot configured, please choose the\n'Pilot Link Properties' capplet first."));
+				return -1;
+			} else {
+				gnome_pilot_client_get_pilot_id_by_name(gpc,
+									pilots->data,  /* this is the first pilot */
+									&pilot);
+				if(i>1) {
+					g_message("too many pilots...");
+					/* need a choose here */
+				}
+				return pilot;
+			}
+		} else {
 			run_error_dialog(_("No pilot configured, please choose the\n'Pilot Link Properties' capplet first."));
 			return -1;
-		} else {
-			if(i==1) 
-				return pilots[0];
-			else {
-				g_message("too many pilots...");
-				return pilots[0];
-			}
-		}
-	} else {
-		run_error_dialog(_("No pilot configured, please choose the\n'Pilot Link Properties' capplet first."));
+		}    
+		break;
+	}
+	case GPILOTD_ERR_NOT_CONNECTED:
+		run_error_dialog(_("Not connected to the gnome-pilot daemon"));
 		return -1;
-	}  
+		break;
+	default:
+		g_warning("gnome_pilot_client_get_pilot_ids(...) = %d",err);
+		run_error_dialog(_("An error occured when trying to fetch\npilot list from the gnome-pilot daemon"));
+		return -1;
+		break;
+	}
 }
 
 int
 main( int argc, char *argv[] )
 {
+	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
+	textdomain (PACKAGE);
+
 	/* we're a capplet */
 	gnome_capplet_init ("backup conduit control applet", NULL, argc, argv, 
 			    NULL,
 			    0, NULL);
 
-	/* get pilot name from gpilotd */
-	/* 1. initialize the gpilotd connection */
-	if (gpilotd_init(&argc,argv)!=0) {
-		run_error_dialog(_("Cannot initialze the GnomePilot Daemon"));
-		g_error(_("Cannot initialze the GnomePilot Daemon"));
-		return -1;
-	}
-
-	/* 2 connect to gpilotd */
-	if (gpilotd_connect()!=0) {
-		run_error_dialog(_("Cannot connect to the GnomePilot Daemon"));
-		g_error(_("Cannot connect to the GnomePilot Daemon"));
-		return -1;
-	}
-    
+	gpc = gnome_pilot_client_new();
+	gnome_pilot_client_connect_to_daemon(gpc);
 	pilotId = get_pilot_id_from_gpilotd();
 	if(pilotId==-1) return -1;
 
-	/* put all code to set things up in here */
-	conduit = gpilotd_conduit_mgmt_new("backup_conduit",pilotId);
+	/* Open the conduit management for "gpbackup1" which is
+	   the id for the backup conduit, as found in backup.conduit */
+	conduit = gnome_pilot_conduit_management_new("gpbackup1",GNOME_PILOT_CONDUIT_MGMT_ID);
+	if (conduit==NULL) {
+		g_warning("Could not create object for conduit. The .conduit file may be missing.");
+		run_error_dialog(_("Could not create object for conduit.\n"
+				   "Perhaps the conduit isn't properly installed ?"));
+		return -1;
+	}
 
+	conduit_config = gnome_pilot_conduit_config_new(conduit,pilotId);
 	load_configuration(&origState,pilotId);
 	curState = dupe_configuration(origState);
 
-	org_activation_state = activated = gpilotd_conduit_mgmt_is_enabled(conduit,pilotId);
+	org_activation_state = activated = gnome_pilot_conduit_config_is_enabled(conduit_config,NULL);
     
 	pilot_capplet_setup();
 
 	/* done setting up, now run main loop */
 	capplet_gtk_main();
 
+	gnome_pilot_conduit_management_destroy(conduit);
 	destroy_configuration(&origState);
 	destroy_configuration(&curState);
 
