@@ -1,4 +1,4 @@
-/* $Id: backup_conduit.c,v 1.20 2000/01/06 03:06:05 eskil Exp $ */
+/* $Id: backup_conduit.c,v 1.26 2000/03/20 14:50:29 eskil Exp $ */
 
 #include <glib.h>
 #include <gnome.h>
@@ -20,6 +20,72 @@
 #include <gpilotd/gnome-pilot-conduit-backup.h>
 #include "backup_conduit.h"
 
+GnomePilotConduit *conduit_get_gpilot_conduit (guint32 pilotId);
+void conduit_destroy_gpilot_conduit (GnomePilotConduit *conduit);
+
+static void 
+load_configuration(ConduitCfg **c,guint32 pilotId) 
+{
+	gchar *prefix;
+	gchar **exclude_files;
+	gint num_of_exclude_files = 0;
+	guint i;
+
+	*c = g_new0(ConduitCfg,1);
+	(*c)->child = -1;
+	
+	prefix = g_strdup_printf("/gnome-pilot.d/backup-conduit/Pilot_%u/",pilotId);
+	
+	gnome_config_push_prefix(prefix);
+	(*c)->backup_dir = gnome_config_get_string("backup_dir");
+	(*c)->updated_only = gnome_config_get_bool("updated_only=TRUE");
+	(*c)->remove_deleted = gnome_config_get_bool("remove_deleted=FALSE");	
+
+	(*c)->exclude_files = NULL;
+	gnome_config_get_vector("exclude_files",
+				&num_of_exclude_files,
+				&exclude_files);
+	if(num_of_exclude_files) {
+		for( i = 0; i < num_of_exclude_files ; i++ ) {
+			(*c)->exclude_files = g_list_append( (*c)->exclude_files , 
+							     g_strdup(exclude_files[i]));
+			g_free(exclude_files[i]);
+		}
+		g_free(exclude_files);
+	}
+	gnome_config_pop_prefix();
+	
+	(*c)->files_in_backup = NULL;
+	if((*c)->backup_dir != NULL && 
+	   mkdir((*c)->backup_dir,(mode_t)0755) < 0) { /* Wow, I never though I would
+							  use octal in C :) */
+		if(errno != EEXIST) {
+			/* YECH! 
+			   CONDUIT_CFG(c.gpilotd_methods)->log_error("Cannot open whatever...");
+			*/
+		}
+	}    
+	(*c)->pilotId = pilotId;
+	g_free(prefix);
+}
+/** this method frees all data from the conduit config */
+static void 
+destroy_configuration(ConduitCfg **c) 
+{
+	g_return_if_fail(c!=NULL);
+	g_return_if_fail(*c!=NULL);
+
+	if((*c)->remove_deleted) {
+		g_list_free((*c)->files_in_backup);
+	}
+	
+	g_list_foreach((*c)->exclude_files,(GFunc)g_free,NULL);
+	g_list_free((*c)->exclude_files);
+	g_free((*c)->backup_dir);
+	g_free(*c);
+	*c = NULL;
+}
+
 /* Helper functions */
 static void
 protect_name(char *d, char *s) {
@@ -38,39 +104,6 @@ protect_name(char *d, char *s) {
 	}
 	*d = '\0';
 }
-static void
-prepare_backup_conduit (GnomePilotConduitBackup *conduit,
-			guint32 pilotId)
-{
-	gchar prefix[45];
-	gchar *backup_dir;
-	gboolean updated_only;
-	gboolean remove_deleted;
-
-	g_snprintf(prefix,44,"/gnome-pilot.d/backup-conduit/Pilot_%u/",pilotId);
-
-	gnome_config_push_prefix(prefix);
-	backup_dir = gnome_config_get_string("backup_dir");
-	updated_only = gnome_config_get_bool("updated_only=TRUE");
-	remove_deleted = gnome_config_get_bool("remove_deleted=FALSE");
-	gnome_config_pop_prefix();
-
-
-	if (backup_dir==NULL) {
-		char file_name[80];
-		g_snprintf (file_name, 79, "%s/pilot/", g_get_home_dir());
-		backup_dir = g_strdup(file_name);
-	}
-	/* let's make sure that this directory exists */
-	if (mkdir (backup_dir, (mode_t)0755 ) < 0) { /* Wow, I never though I would use octal in C :)*/
-		if(errno != EEXIST) {
-			g_warning (_("Unable to create directory:\n\t%s\n"), backup_dir);
-			gnome_pilot_conduit_error (GNOME_PILOT_CONDUIT(conduit),
-						   _("Unable to create directory:\n\t%s\n"), 
-						   backup_dir);
-		}
-	}
-}
 
 /* Signals */
 static gint
@@ -110,14 +143,11 @@ gnome_real_pilot_conduit_backup_backup (GnomePilotConduitBackup *conduit,
 	g_return_val_if_fail (GNOME_IS_PILOT_CONDUIT_BACKUP (conduit), -1);
 	
 	/* let's see first if we should actually touch this db */
-	if( cfg->exclude_files != NULL ) {
-	  iterator = cfg->exclude_files;
-	  while( iterator != NULL ) {
-	    if( ! g_strcasecmp(iterator->data, PI_DBINFO (dbinfo)->name) ) {
-	      return 0;
-	    }
-	    iterator = iterator->next;
-	  }
+	for (iterator = cfg->exclude_files; iterator; iterator = iterator->next) {
+		if( ! g_strcasecmp(iterator->data, PI_DBINFO (dbinfo)->name) ) {
+			g_message("excluded %s",PI_DBINFO (dbinfo)->name);
+			return 0;
+		}
 	}
 
 	if (cfg->backup_dir == NULL) {
@@ -128,7 +158,8 @@ gnome_real_pilot_conduit_backup_backup (GnomePilotConduitBackup *conduit,
 	} 
 
 	strcpy (name, cfg->backup_dir);
-	strcat (name,"/");
+	if (cfg->backup_dir[strlen(cfg->backup_dir)-1] != '/')
+		strcat (name,"/");
 	protect_name (name + strlen (name), PI_DBINFO (dbinfo)->name);
 
 	if (PI_DBINFO (dbinfo)->flags & dlpDBFlagResource)
@@ -149,9 +180,17 @@ gnome_real_pilot_conduit_backup_backup (GnomePilotConduitBackup *conduit,
 	if (cfg->updated_only) {
 		if (stat (name, &statb) == 0) {
 			if (PI_DBINFO (dbinfo)->modifyDate == statb.st_mtime) {
+				g_message(_("%s not modified since last sync"),
+					  PI_DBINFO (dbinfo)->name);
+#if 0
+				gnome_pilot_conduit_message(GNOME_PILOT_CONDUIT(conduit),
+							    _("%s not modified since last sync"),
+							    PI_DBINFO (dbinfo)->name);
+#endif
+				
 				return 0;
 			}
-		}
+		} 
 	}
 
 	PI_DBINFO (dbinfo)->flags &= 0xff;
@@ -185,6 +224,7 @@ gnome_real_pilot_conduit_backup_backup (GnomePilotConduitBackup *conduit,
 		return 0;
 	}
 }
+
 GnomePilotConduit *
 conduit_get_gpilot_conduit (guint32 pilotId)
 {
@@ -203,6 +243,7 @@ conduit_get_gpilot_conduit (guint32 pilotId)
 
 	return GNOME_PILOT_CONDUIT (retval);
 }
+
 void
 conduit_destroy_gpilot_conduit (GnomePilotConduit *conduit)
 {
