@@ -6,15 +6,15 @@
 #include <pwd.h>
 #include <sys/types.h>
 #include <signal.h>
+#include <ctype.h>
 #include <gnome.h>
 
 #include <config.h>
 #include <capplet-widget.h>
 
-#include <gpilotd/gpilotd-conduit-mgmt.h>
-#include <gpilotd/gpilotd-app.h>
-#include <gpilotd/gpilotd-app-dummy-callbacks.h>
-
+#include <libgpilotdCM/gnome-pilot-conduit-management.h>
+#include <libgpilotdCM/gnome-pilot-conduit-config.h>
+#include <gpilotd/gnome-pilot-client.h>
 #include "expense_conduit.h"
 
 /* tell changes callbacks to ignore changes or not */
@@ -29,7 +29,9 @@ GtkWidget *cfgStateWindow=NULL;
 GtkWidget *dialogWindow=NULL;
 
 gboolean activated,org_activation_state;
-GnomePilotConduitMgmt *conduit;
+GnomePilotConduitManagement *conduit;
+GnomePilotConduitConfig *conduit_config;
+
 ConduitCfg *origState = NULL;
 ConduitCfg *curState = NULL;
 
@@ -45,6 +47,7 @@ static void setStateCfg(GtkWidget *w, ConduitCfg *state);
 
 gint pilotId;
 CORBA_Environment ev;
+static GnomePilotClient *gpc;
 
 #define DATE_OPTIONS_COUNT 4
 typedef struct {
@@ -67,13 +70,105 @@ typedef struct {
 static WriteoutSetting_t writeout_options[] = { { N_("Simple"), eSimpleFormat},
                                                 { N_("Complex"), eComplexFormat} };
 
+
+static void 
+load_configuration(ConduitCfg **c,guint32 pilotId) 
+{
+	gchar *prefix;
+	gchar *tempbuf = NULL;
+
+	g_assert(c!=NULL);
+	*c = g_new0(ConduitCfg,1);
+	(*c)->child = -1;
+
+	prefix = g_strdup_printf("/gnome-pilot.d/expense-conduit/Pilot_%u/",pilotId);
+  
+	gnome_config_push_prefix(prefix);
+	(*c)->dir = gnome_config_get_string( "dir");
+	(*c)->dateFormat = gnome_config_get_string( "date_format=%x");
+	(*c)->outputFormat = gnome_config_get_int("output_format=0");
+	tempbuf = gnome_config_get_string("dir mode=0700");
+	(*c)->dirMode =(mode_t)strtol(tempbuf,NULL,0);
+	g_free(tempbuf);
+	tempbuf = gnome_config_get_string("file mode=0600");
+	(*c)->fileMode =(mode_t)strtol(tempbuf,NULL,0);
+	g_free(tempbuf);
+
+	gnome_config_pop_prefix();
+
+	(*c)->pilotId = pilotId;
+
+	/* make a default directory if nothing was defined */
+	if((*c)->dir == NULL) {
+		gnome_pilot_client_get_pilot_base_dir_by_id(gpc,pilotId,&tempbuf);
+		(*c)->dir =g_strdup_printf ("%s/expense", tempbuf);
+		g_free(tempbuf);
+	}
+	g_free(prefix);
+}
+
+
+static void 
+save_configuration(ConduitCfg *c) 
+{
+	gchar *prefix;
+
+	g_assert(c!=NULL);
+
+	prefix = g_strdup_printf("/gnome-pilot.d/expense-conduit/Pilot_%u/",c->pilotId);
+
+	gnome_config_push_prefix(prefix);
+	gnome_config_set_string("dir", c->dir);
+	gnome_config_set_string("date_format", c->dateFormat);
+	gnome_config_set_int("output_format", c->outputFormat);
+	g_snprintf(prefix,255,"0%o", c->dirMode);
+	gnome_config_set_string("dir mode", prefix);
+	g_snprintf(prefix,255,"0%o", c->fileMode);
+	gnome_config_set_string("file mode", prefix);
+
+	gnome_config_pop_prefix();
+
+	gnome_config_sync();
+	gnome_config_drop_all();
+	g_free(prefix);
+}
+
+static ConduitCfg*
+dupe_configuration(ConduitCfg *c) {
+	ConduitCfg *retval;
+	g_assert(c!=NULL);
+	retval = g_new0(ConduitCfg,1);
+	retval->dir = g_strdup(c->dir);
+	retval->dateFormat = g_strdup(c->dateFormat);
+	retval->outputFormat = c->outputFormat;
+	retval->dirMode = c->dirMode;
+	retval->fileMode = c->fileMode;
+
+	retval->pilotId = c->pilotId;
+
+	return retval;
+}
+
+/** this method frees all data from the conduit config */
+static void 
+destroy_configuration(ConduitCfg **c) 
+{
+	g_assert(c!=NULL);
+	g_assert(*c!=NULL);
+	g_free( (*c)->dir);
+	g_free( (*c)->dateFormat);
+	g_free(*c);
+	*c = NULL;
+}
+
+
 static void
 setSettings(ConduitCfg* conduitCfg)
 {
-        if(activated)
-                gpilotd_conduit_mgmt_enable(conduit,pilotId,GnomePilotConduitSyncTypeSynchronize);
+       if(activated)
+               	gnome_pilot_conduit_config_enable(conduit_config,GnomePilotConduitSyncTypeSynchronize);
         else
-                gpilotd_conduit_mgmt_disable(conduit,pilotId);
+                gnome_pilot_conduit_config_disable(conduit_config);
         save_configuration(conduitCfg);
 }
 
@@ -177,7 +272,8 @@ statechange_cb(GtkEditable    *editable, const gchar    *text,
 }
 
 	
-void about_cb (GtkWidget *widget, gpointer data) 
+static void 
+about_cb (GtkWidget *widget, gpointer data) 
 {
         GtkWidget *about;
         const gchar *authors[] = {_("Patrick Decowski <decowski@mit.edu>"),NULL};
@@ -206,7 +302,7 @@ static GtkWidget
 *createStateCfgWindow(void)
 {
         GtkWidget *vbox, *table;
-        GtkWidget *entry, *label;
+        GtkWidget *label;
         GtkWidget *button;
 
         vbox = gtk_vbox_new(FALSE, GNOME_PAD);
@@ -234,7 +330,6 @@ static void
 setStateCfg(GtkWidget *widget,ConduitCfg *cfg)
 {
         GtkWidget *button;
-        gchar num[40];
 
         button = gtk_object_get_data(GTK_OBJECT(widget), "conduit_on_off");
 
@@ -284,7 +379,7 @@ static GtkWidget
         GtkWidget *menuItem, *optionMenu;
         GtkMenu   *menu;
 
-        int i, count, widget_offset;
+        int i, count=0, widget_offset;
 
 	vbox = gtk_vbox_new(FALSE, GNOME_PAD);
 
@@ -469,7 +564,8 @@ pilot_capplet_setup(void)
         gtk_widget_show_all(capplet);
 }
 
-void run_error_dialog(gchar *mesg,...) 
+static void 
+run_error_dialog(gchar *mesg,...) 
 {
         char tmp[80];
         va_list ap;
@@ -481,56 +577,65 @@ void run_error_dialog(gchar *mesg,...)
         va_end(ap);
 }
 
-
-gint get_pilot_id_from_gpilotd() 
+static gint 
+get_pilot_id_from_gpilotd() 
 {
-	gint *pilots;
-	int i;
+	GList *pilots=NULL;
+	gint pilot;
+	int i,err;
   
 	i=0;
-	gpilotd_get_pilot_ids(&pilots);
-	if(pilots) {
-		while(pilots[i]!=-1) { g_message("pilot %d = \"%d\"",i,pilots[i]); i++; }
-		if(i==0) {
+	/* we don't worry about leaking here, so pilots isn't freed */
+	switch(err = gnome_pilot_client_get_pilots(gpc,&pilots)) {
+	case GPILOTD_OK: {
+		if(pilots) {
+			for(i=0;i<g_list_length(pilots);i++) {
+				g_message("pilot %d = \"%s\"",i,(gchar*)g_list_nth(pilots,i)->data); 
+			}
+			if(i==0) {
+				run_error_dialog(_("No pilot configured, please choose the\n'Pilot Link Properties' capplet first."));
+				return -1;
+			} else {
+				gnome_pilot_client_get_pilot_id_by_name(gpc,
+									pilots->data,  /* this is the first pilot */
+									&pilot);
+				if(i>1) {
+					g_message("too many pilots...");
+					/* need a choose here */
+				}
+				return pilot;
+			}
+		} else {
 			run_error_dialog(_("No pilot configured, please choose the\n'Pilot Link Properties' capplet first."));
 			return -1;
-		} else {
-			if(i==1) 
-				return pilots[0];
-			else {
-				g_message("too many pilots...");
-				return pilots[0];
-			}
-		}
-	} else {
-		run_error_dialog(_("No pilot configured, please choose the\n'Pilot Link Properties' capplet first."));
+		}    
+		break;
+	}
+	case GPILOTD_ERR_NOT_CONNECTED:
+		run_error_dialog(_("Not connected to the gnome-pilot daemon"));
 		return -1;
-	}  
+		break;
+	default:
+		g_warning("gnome_pilot_client_get_pilot_ids(...) = %d",err);
+		run_error_dialog(_("An error occured when trying to fetch\npilot list from the gnome-pilot daemon"));
+		return -1;
+		break;
+	}
 }
 
 int
 main( int argc, char *argv[] )
 {
+	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
+	textdomain (PACKAGE);
+
         /* we're a capplet */
         gnome_capplet_init ("Expense conduit control applet", NULL, argc, argv, 
                             NULL,
                             0, NULL);
 
-        /* get pilot name from gpilotd */
-        /* 1. initialize the gpilotd connection */
-        if (gpilotd_init(&argc,argv)!=0) {
-                run_error_dialog(_("Cannot initialze the GnomePilot Daemon"));
-                g_error(_("Cannot initialze the GnomePilot Daemon"));
-                return -1;
-        }
-    
-        /* 2 connect to gpilotd */
-        if (gpilotd_connect()!=0) {
-                run_error_dialog(_("Cannot connect to the GnomePilot Daemon"));
-                g_error(_("Cannot connect to the GnomePilot Daemon"));
-                return -1;
-        }
-    
+  	gpc = GNOME_PILOT_CLIENT(gnome_pilot_client_new());
+	gnome_pilot_client_connect_to_daemon(gpc);
         pilotId = get_pilot_id_from_gpilotd();
         if(pilotId==-1) return -1;
 
@@ -538,13 +643,13 @@ main( int argc, char *argv[] )
 
         load_configuration(&origState,pilotId);
         curState = dupe_configuration(origState);
-        conduit = gpilotd_conduit_mgmt_new("expense_conduit",pilotId);
 
-        org_activation_state = activated = gpilotd_conduit_mgmt_is_enabled(conduit,pilotId);
-    
+        conduit = gnome_pilot_conduit_management_new("gpexpense1",GNOME_PILOT_CONDUIT_MGMT_ID);
+        conduit_config = gnome_pilot_conduit_config_new(conduit,pilotId);
+        org_activation_state = activated = gnome_pilot_conduit_config_is_enabled(conduit_config,NULL);
+
         pilot_capplet_setup();
 
-
         /* done setting up, now run main loop */
         capplet_gtk_main();
         return 0;
