@@ -10,9 +10,9 @@
 #include <config.h>
 #include <capplet-widget.h>
 
-#include "gpilotd/gpilotd-conduit-mgmt.h"
-#include "gpilotd/gpilotd-app.h"
-#include "gpilotd/gpilotd-app-dummy-callbacks.h"
+#include <libgpilotdCM/gnome-pilot-conduit-management.h>
+#include <libgpilotdCM/gnome-pilot-conduit-config.h>
+#include <gpilotd/gnome-pilot-client.h>
 
 #include "file_conduit.h"
 
@@ -28,8 +28,8 @@ GtkWidget *cfgStateWindow=NULL;
 GtkWidget *dialogWindow=NULL;
 
 gboolean activated,org_activation_state;
-GnomePilotConduitMgmt *conduit;
-
+GnomePilotConduitManagement *conduit;
+GnomePilotConduitConfig *conduit_config;
 ConduitCfg *origState = NULL;
 ConduitCfg *curState = NULL;
 
@@ -42,15 +42,50 @@ static void setStateCfg(GtkWidget *w);
 
 gint pilotId;
 CORBA_Environment ev;
+static GnomePilotClient *gpc;
+
+static void 
+load_configuration(ConduitCfg **c,
+		   guint32 pilotId) 
+{
+	g_assert(c!=NULL);
+	*c = g_new0(ConduitCfg,1);
+	(*c)->pilotId = pilotId;
+}
+
+static void 
+save_configuration(ConduitCfg *c) 
+{
+	g_return_if_fail(c!=NULL);
+}
+
+static ConduitCfg*
+dupe_configuration(ConduitCfg *c) {
+	ConduitCfg *retval;
+	g_return_val_if_fail(c!=NULL,NULL);
+	retval = g_new0(ConduitCfg,1);
+	retval->pilotId = c->pilotId;
+	return retval;
+}
+
+/** this method frees all data from the conduit config */
+static void 
+destroy_configuration(ConduitCfg **c) 
+{
+	g_return_if_fail(c!=NULL);
+	g_return_if_fail(*c!=NULL);
+	g_free(*c);
+	*c = NULL;
+}
 
 static void
 doTrySettings(GtkWidget *widget, ConduitCfg *conduitCfg)
 {
     readStateCfg(cfgStateWindow);
     if(activated)
-      gpilotd_conduit_mgmt_enable(conduit,pilotId,GnomePilotConduitSyncTypeCustom);
+      gnome_pilot_conduit_config_enable(conduit_config,GnomePilotConduitSyncTypeCustom);
     else
-      gpilotd_conduit_mgmt_disable(conduit,pilotId);
+      gnome_pilot_conduit_config_disable(conduit_config);
 }
 
 static void
@@ -68,46 +103,9 @@ doRevertSettings(GtkWidget *widget, ConduitCfg *conduitCfg)
     setStateCfg(cfgStateWindow);
 }
 
-static void
-insert_dir_callback (GtkEditable    *editable, const gchar    *text,
-		     gint len, gint *position, void *data)
+static void 
+about_cb (GtkWidget *widget, gpointer data) 
 {
-    gint i;
-    gchar *curname;
-
-    curname = gtk_entry_get_text(GTK_ENTRY(editable));
-    if (*curname == '\0' && len > 0) {
-	if (isspace(text[0])) {
-	    gtk_signal_emit_stop_by_name(GTK_OBJECT(editable), "insert_text");
-	    return;
-	}
-    } else {
-	for (i=0; i<len; i++) {
-	    if (isspace(text[i])) {
-		gtk_signal_emit_stop_by_name(GTK_OBJECT(editable), 
-					     "insert_text");
-		return;
-	    }
-	}
-    }
-}
-static void
-insert_dir_callback2(GtkEditable    *editable, const gchar    *text,
-		      gint            length, gint           *position,
-		      void *data)
-{
-    if (!ignore_changes)
-        capplet_widget_state_changed(CAPPLET_WIDGET(capplet), TRUE);
-}
-
-static void
-clist_changed(GtkWidget *widget, gpointer data)
-{
-    if (!ignore_changes)
-	capplet_widget_state_changed(CAPPLET_WIDGET(capplet), TRUE);
-}
-	
-void about_cb (GtkWidget *widget, gpointer data) {
   GtkWidget *about;
   const gchar *authors[] = {_("Eskil Heyn Olsen <deity@eskil.dk>"),NULL};
   
@@ -134,7 +132,7 @@ static GtkWidget
 *createStateCfgWindow(void)
 {
     GtkWidget *vbox, *table;
-    GtkWidget *entry, *label;
+    GtkWidget *label;
     GtkWidget *button;
 
     vbox = gtk_vbox_new(FALSE, GNOME_PAD);
@@ -161,7 +159,6 @@ static void
 setStateCfg(GtkWidget *cfg)
 {
     GtkWidget *button;
-    gchar num[40];
 
     button = gtk_object_get_data(GTK_OBJECT(cfg), "conduit_on_off");
 
@@ -218,7 +215,9 @@ pilot_capplet_setup(void)
     gtk_widget_show_all(capplet);
 }
 
-void run_error_dialog(gchar *mesg,...) {
+static void 
+run_error_dialog(gchar *mesg,...) 
+{
   char tmp[80];
   va_list ap;
 
@@ -229,55 +228,66 @@ void run_error_dialog(gchar *mesg,...) {
   va_end(ap);
 }
 
-gint get_pilot_id_from_gpilotd() {
-	gint *pilots;
-	int i;
+static gint 
+get_pilot_id_from_gpilotd() 
+{
+	GList *pilots=NULL;
+	gint pilot;
+	int i,err;
   
 	i=0;
-	gpilotd_get_pilot_ids(&pilots);
-	if(pilots) {
-		while(pilots[i]!=-1) { g_message("pilot %d = \"%d\"",i,pilots[i]); i++; }
-		if(i==0) {
+	/* we don't worry about leaking here, so pilots isn't freed */
+	switch(err = gnome_pilot_client_get_pilots(gpc,&pilots)) {
+	case GPILOTD_OK: {
+		if(pilots) {
+			for(i=0;i<g_list_length(pilots);i++) {
+				g_message("pilot %d = \"%s\"",i,(gchar*)g_list_nth(pilots,i)->data); 
+			}
+			if(i==0) {
+				run_error_dialog(_("No pilot configured, please choose the\n'Pilot Link Properties' capplet first."));
+				return -1;
+			} else {
+				gnome_pilot_client_get_pilot_id_by_name(gpc,
+									pilots->data,  /* this is the first pilot */
+									&pilot);
+				if(i>1) {
+					g_message("too many pilots...");
+					/* need a choose here */
+				}
+				return pilot;
+			}
+		} else {
 			run_error_dialog(_("No pilot configured, please choose the\n'Pilot Link Properties' capplet first."));
 			return -1;
-		} else {
-			if(i==1) 
-				return pilots[0];
-			else {
-				g_message("too many pilots...");
-				return pilots[0];
-			}
-		}
-	} else {
-		run_error_dialog(_("No pilot configured, please choose the\n'Pilot Link Properties' capplet first."));
+		}    
+		break;
+	}
+	case GPILOTD_ERR_NOT_CONNECTED:
+		run_error_dialog(_("Not connected to the gnome-pilot daemon"));
 		return -1;
-	}  
+		break;
+	default:
+		g_warning("gnome_pilot_client_get_pilot_ids(...) = %d",err);
+		run_error_dialog(_("An error occured when trying to fetch\npilot list from the gnome-pilot daemon"));
+		return -1;
+		break;
+	}
 }
 
 int
 main( int argc, char *argv[] )
 {
+    bindtextdomain (PACKAGE, GNOMELOCALEDIR);
+    textdomain (PACKAGE);
+	
     /* we're a capplet */
     gnome_capplet_init ("file conduit control applet", NULL, argc, argv, 
 			NULL,
 			0, NULL);
 
-    /* get pilot name from gpilotd */
-    /* 1. initialize the gpilotd connection */
-    if (gpilotd_init(&argc,argv)!=0) {
-	    run_error_dialog(_("Cannot initialze the GnomePilot Daemon"));
-	    g_error(_("Cannot initialze the GnomePilot Daemon"));
-	    return -1;
-    }
-    
-    /* 2 connect to gpilotd */
-    if (gpilotd_connect()!=0) {
-	    run_error_dialog(_("Cannot connect to the GnomePilot Daemon"));
-	    g_error(_("Cannot connect to the GnomePilot Daemon"));
-	    return -1;
-    }
-
-    
+   
+    gpc = gnome_pilot_client_new();
+    gnome_pilot_client_connect_to_daemon(gpc);
     pilotId = get_pilot_id_from_gpilotd();
     if(!pilotId) return -1;
 
@@ -286,14 +296,18 @@ main( int argc, char *argv[] )
     curState = dupe_configuration(origState);
 
     /* put all code to set things up in here */
-    conduit = gpilotd_conduit_mgmt_new("file_conduit",pilotId);
-
-    org_activation_state = activated = gpilotd_conduit_mgmt_is_enabled(conduit,pilotId);
+    conduit = gnome_pilot_conduit_management_new("gpfile1",GNOME_PILOT_CONDUIT_MGMT_ID);
+    if (conduit==NULL) return -1;
+    conduit_config = gnome_pilot_conduit_config_new(conduit,pilotId);
+    org_activation_state = activated = gnome_pilot_conduit_config_is_enabled(conduit_config,NULL);
     
     pilot_capplet_setup();
 
 
     /* done setting up, now run main loop */
     capplet_gtk_main();
+    
+    gnome_pilot_conduit_management_destroy(conduit);
+
     return 0;
 }    
