@@ -5,14 +5,15 @@
 #include <pwd.h>
 #include <sys/types.h>
 #include <signal.h>
+#include <ctype.h>
 #include <gnome.h>
 
 #include <config.h>
 #include <capplet-widget.h>
 
-#include <gpilotd/gpilotd-conduit-mgmt.h>
-#include <gpilotd/gpilotd-app.h>
-#include <gpilotd/gpilotd-app-dummy-callbacks.h>
+#include <libgpilotdCM/gnome-pilot-conduit-management.h>
+#include <libgpilotdCM/gnome-pilot-conduit-config.h>
+#include <gpilotd/gnome-pilot-client.h>
 
 #include "memo_file_conduit.h"
 
@@ -27,7 +28,8 @@ GtkWidget *cfgOptionsWindow=NULL;
 GtkWidget *cfgStateWindow=NULL;
 GtkWidget *dialogWindow=NULL;
 
-GnomePilotConduitMgmt *conduit;
+GnomePilotConduitManagement *conduit;
+GnomePilotConduitConfig *conduit_config;
 
 ConduitCfg *origState = NULL;
 ConduitCfg *curState = NULL;
@@ -43,7 +45,7 @@ static void setStateCfg(GtkWidget *w, ConduitCfg *state);
 static void readOptionsCfg(GtkWidget *w, ConduitCfg *state);
 static void setOptionsCfg(GtkWidget *w, ConduitCfg *state);
 
-gint pilotId;
+static gint pilotId;
 CORBA_Environment ev;
 
 /* This array must be in the same order as enumerations
@@ -58,16 +60,126 @@ static gchar* sync_options[] ={ N_("Disabled"),
 				N_("Merge To Pilot")};
 #define SYNC_OPTIONS_COUNT 6
 
+static GnomePilotClient *gpc;
+
+static void 
+load_configuration(ConduitCfg **c,guint32 pilotId) 
+{
+	gchar prefix[256];
+	gchar *buf;
+	g_return_if_fail(c!=NULL);
+
+	g_snprintf(prefix,255,CONFIG_PREFIX,pilotId);
+ 
+	*c = g_new0(ConduitCfg,1);
+	gnome_config_push_prefix(prefix);
+	(*c)->sync_type = GnomePilotConduitSyncTypeCustom; /* this will be reset by capplet */
+	(*c)->open_secret = gnome_config_get_bool("open secret=FALSE"); 
+
+	buf = gnome_config_get_string("file mode=0600");
+	(*c)->file_mode =(mode_t)strtol(buf,NULL,0);
+	g_free(buf);
+
+	buf = gnome_config_get_string("dir mode=0700");
+	(*c)->dir_mode =(mode_t)strtol(buf,NULL,0);
+	g_free(buf);
+
+	buf = gnome_config_get_string("secret mode=0600");
+	(*c)->secret_mode =(mode_t)strtol(buf,NULL,0);
+	g_free(buf);
+  
+	(*c)->dir = gnome_config_get_string("dir");
+	(*c)->ignore_end=gnome_config_get_string("ignore end");
+	(*c)->ignore_start=gnome_config_get_string("ignore start");
+	gnome_config_pop_prefix();
+	if((*c)->dir==NULL) {
+		gnome_pilot_client_get_pilot_base_dir_by_id(gpc,pilotId,&buf);		
+		(*c)->dir =g_strdup_printf("%s/memos",buf);
+		g_free(buf);
+	}
+
+	(*c)->pilotId = pilotId;
+}
+
+static void 
+save_configuration(ConduitCfg *c) 
+{
+	gchar prefix[256];
+
+	g_return_if_fail(c!=NULL);
+	g_snprintf(prefix,255,CONFIG_PREFIX,c->pilotId);
+
+	gnome_config_push_prefix(prefix);
+	gnome_config_set_bool("open secret",c->open_secret); 
+	g_snprintf(prefix,255,"0%o",c->secret_mode);
+	gnome_config_set_string("secret mode",prefix);
+	g_snprintf(prefix,255,"0%o",c->file_mode);
+	gnome_config_set_string("file mode",prefix);
+	g_snprintf(prefix,255,"0%o",c->dir_mode);
+	gnome_config_set_string("dir mode",prefix);
+	gnome_config_set_string("dir",c->dir);
+	gnome_config_set_string("ignore end",c->ignore_end);
+	gnome_config_set_string("ignore start",c->ignore_start);
+	gnome_config_pop_prefix();
+
+	gnome_config_sync();
+	gnome_config_drop_all();
+
+}
+
+static void 
+copy_configuration(ConduitCfg *d, ConduitCfg *c)
+{
+	g_return_if_fail(c!=NULL);
+	g_return_if_fail(d!=NULL);
+	d->sync_type=c->sync_type;
+	if(d->dir) g_free(d->dir);
+	d->dir = g_strdup(c->dir);
+	if(d->ignore_start) g_free(d->ignore_start);
+	d->ignore_start = g_strdup(c->ignore_start);
+	if(d->ignore_end) g_free(d->ignore_end);
+	d->ignore_end = g_strdup(c->ignore_end);
+	d->file_mode = c->file_mode;
+	d->dir_mode = c->dir_mode;
+	d->secret_mode = c->secret_mode;
+	d->open_secret = c->open_secret;
+	d->pilotId = c->pilotId;
+}
+
+static ConduitCfg*
+dupe_configuration(ConduitCfg *c) 
+{
+	ConduitCfg *d;
+	g_return_val_if_fail(c!=NULL,NULL);
+	d = g_new0(ConduitCfg,1);
+	d->dir=NULL;
+	copy_configuration(d,c);
+	return d;
+}
+
+
+
+static void 
+destroy_configuration(ConduitCfg **c) 
+{
+	g_return_if_fail(c!=NULL);
+	if((*c)->dir) g_free((*c)->dir);
+	if((*c)->ignore_start) g_free((*c)->ignore_start);
+	if((*c)->ignore_end) g_free((*c)->ignore_end);
+	g_free(*c);
+	*c = NULL;
+}
+
 static void 
 setSettings(ConduitCfg* conduitCfg)
 {
 	if(conduitCfg->sync_type!=GnomePilotConduitSyncTypeCustom)
-		gpilotd_conduit_mgmt_enable_with_first_sync(conduit,pilotId,
-							    conduitCfg->sync_type,
-							    conduitCfg->sync_type,
-							    TRUE);
+		gnome_pilot_conduit_config_enable_with_first_sync(conduit_config,
+								  conduitCfg->sync_type,
+								  conduitCfg->sync_type,
+								  TRUE);
 	else
-		gpilotd_conduit_mgmt_disable(conduit,pilotId);
+		gnome_pilot_conduit_config_disable(conduit_config);
 
 	save_configuration(conduitCfg);
 }
@@ -153,13 +265,15 @@ static void
 secret_toggled_cb(GtkWidget *widget, gpointer data) 
 {
 	curState->open_secret = GTK_TOGGLE_BUTTON(widget)->active;
-	gtk_widget_set_sensitive(gtk_object_get_data(cfgOptionsWindow,"secret_mode"),curState->open_secret);
-	gtk_widget_set_sensitive(gtk_object_get_data(cfgOptionsWindow,"secret_label"),curState->open_secret);
+	gtk_widget_set_sensitive(gtk_object_get_data(GTK_OBJECT(cfgOptionsWindow),"secret_mode"),curState->open_secret);
+	gtk_widget_set_sensitive(gtk_object_get_data(GTK_OBJECT(cfgOptionsWindow),"secret_label"),curState->open_secret);
 	if(!ignore_changes) {
 		capplet_widget_state_changed(CAPPLET_WIDGET(capplet), TRUE);
 	}
 }
-void about_cb (GtkWidget *widget, gpointer data) 
+
+static void 
+about_cb (GtkWidget *widget, gpointer data) 
 {
 	GtkWidget *about;
 	const gchar *authors[] = {_("Eskil Heyn Olsen <deity@eskil.dk>"),
@@ -200,7 +314,7 @@ static GtkWidget
 *createStateCfgWindow(void)
 {
 	GtkWidget *vbox, *table;
-	GtkWidget *label, *button;
+	GtkWidget *label;
 	GtkWidget *optionMenu,*menuItem;
 	GtkMenu   *menu;
 	gint i;
@@ -237,25 +351,6 @@ static GtkWidget
 	return vbox;
 }
 
-
-static GnomePilotConduitSyncType
-sync_type_str_to_enum(gchar *s)
-{
-	gint i;
-	for(i=0;i<SYNC_OPTIONS_COUNT;i++) {
-		if (strcmp (s, sync_options[i]) == 0) {
-			return (GnomePilotConduitSyncType)i;
-		}
-	}
-	return GnomePilotConduitSyncTypeCustom;
-}
-
-static gchar *
-sync_type_enum_to_str(GnomePilotConduitSyncType s)
-{
-	return sync_options[s];
-}
-
 static void
 setStateCfg(GtkWidget *widget,ConduitCfg *cfg)
 {
@@ -271,8 +366,8 @@ setStateCfg(GtkWidget *widget,ConduitCfg *cfg)
 	/* Here were are relying on the items in menu being the same 
 	   order as in GnomePilotConduitSyncType. */
 	gtk_option_menu_set_history(optionMenu,(int)cfg->sync_type);
-	gtk_widget_set_sensitive(gtk_object_get_data(cfgOptionsWindow,"secret_mode"),cfg->open_secret);
-	gtk_widget_set_sensitive(gtk_object_get_data(cfgOptionsWindow,"secret_label"),cfg->open_secret);
+	gtk_widget_set_sensitive(gtk_object_get_data(GTK_OBJECT(cfgOptionsWindow),"secret_mode"),cfg->open_secret);
+	gtk_widget_set_sensitive(gtk_object_get_data(GTK_OBJECT(cfgOptionsWindow),"secret_label"),cfg->open_secret);
 	gtk_widget_set_sensitive(cfgOptionsWindow,cfg->sync_type!=GnomePilotConduitSyncTypeCustom);
 	ignore_changes = FALSE;
 }
@@ -357,15 +452,17 @@ static void
 setOptionsCfg(GtkWidget *pilotcfg, ConduitCfg *state)
 {
         gchar buf[8];
-	GtkWidget *dir,*ignore_end,*ignore_start,*dir_mode, *file_mode,*secret_mode;
+	GtkWidget *dir,*ignore_end,*ignore_start,*dir_mode;
+	GtkWidget *secret_button, *file_mode,*secret_mode;
 
-	dir  = gtk_object_get_data(GTK_OBJECT(pilotcfg), "dir");
+	dir = gtk_object_get_data(GTK_OBJECT(pilotcfg), "dir");
 	ignore_end  = gtk_object_get_data(GTK_OBJECT(pilotcfg), "ignore_end");
-	ignore_start  = gtk_object_get_data(GTK_OBJECT(pilotcfg), "ignore_start");
+	ignore_start = gtk_object_get_data(GTK_OBJECT(pilotcfg), "ignore_start");
 	dir_mode  = gtk_object_get_data(GTK_OBJECT(pilotcfg), "dir_mode");
 	file_mode = gtk_object_get_data(GTK_OBJECT(pilotcfg), "file_mode");
 	secret_mode = gtk_object_get_data(GTK_OBJECT(pilotcfg), "secret_mode");
-
+	secret_button = gtk_object_get_data(GTK_OBJECT(pilotcfg),"secret_on");
+	
 	g_assert(dir!=NULL);
 
 	ignore_changes = TRUE;
@@ -378,7 +475,7 @@ setOptionsCfg(GtkWidget *pilotcfg, ConduitCfg *state)
 	gtk_entry_set_text(GTK_ENTRY(file_mode),buf);
 	g_snprintf(buf,7,"0%o",state->secret_mode);
 	gtk_entry_set_text(GTK_ENTRY(secret_mode),buf);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gtk_object_get_data(pilotcfg,"secret_on")),curState->open_secret);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(secret_button),curState->open_secret);
 	ignore_changes = FALSE;
 }
 
@@ -450,7 +547,8 @@ pilot_capplet_setup(void)
 	gtk_widget_show_all(capplet);
 }
 
-void run_error_dialog(gchar *mesg,...) 
+static void 
+run_error_dialog(gchar *mesg,...) 
 {
 	char tmp[80];
 	va_list ap;
@@ -462,64 +560,74 @@ void run_error_dialog(gchar *mesg,...)
 	va_end(ap);
 }
 
-
-gint get_pilot_id_from_gpilotd() 
+static gint 
+get_pilot_id_from_gpilotd() 
 {
-	gint *pilots;
-	int i;
+	GList *pilots=NULL;
+	gint pilot;
+	int i,err;
   
 	i=0;
-	gpilotd_get_pilot_ids(&pilots);
-	if(pilots) {
-		while(pilots[i]!=-1) { g_message("pilot %d = \"%d\"",i,pilots[i]); i++; }
-		if(i==0) {
+	/* we don't worry about leaking here, so pilots isn't freed */
+	switch(err = gnome_pilot_client_get_pilots(gpc,&pilots)) {
+	case GPILOTD_OK: {
+		if(pilots) {
+			for(i=0;i<g_list_length(pilots);i++) {
+				g_message("pilot %d = \"%s\"",i,(gchar*)g_list_nth(pilots,i)->data); 
+			}
+			if(i==0) {
+				run_error_dialog(_("No pilot configured, please choose the\n'Pilot Link Properties' capplet first."));
+				return -1;
+			} else {
+				gnome_pilot_client_get_pilot_id_by_name(gpc,
+									pilots->data,  /* this is the first pilot */
+									&pilot);
+				if(i>1) {
+					g_message("too many pilots...");
+					/* need a choose here */
+				}
+				return pilot;
+			}
+		} else {
 			run_error_dialog(_("No pilot configured, please choose the\n'Pilot Link Properties' capplet first."));
 			return -1;
-		} else {
-			if(i==1) { 
-				return pilots[0];
-			} else {
-				g_message("too many pilots...");
-				return pilots[0];
-			}
-		}
-	} else {
-		run_error_dialog(_("No pilot configured, please choose the\n'Pilot Link Properties' capplet first."));
+		}    
+		break;
+	}
+	case GPILOTD_ERR_NOT_CONNECTED:
+		run_error_dialog(_("Not connected to the gnome-pilot daemon"));
 		return -1;
-	}  
+		break;
+	default:
+		g_warning("gnome_pilot_client_get_pilot_ids(...) = %d",err);
+		run_error_dialog(_("An error occured when trying to fetch\npilot list from the gnome-pilot daemon"));
+		return -1;
+		break;
+	}
 }
 
 int
 main( int argc, char *argv[] )
 {
+	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
+	textdomain (PACKAGE);
+
 	/* we're a capplet */
 	gnome_capplet_init ("memo_file conduit control applet", NULL, argc, argv, 
 			    NULL, 0, NULL);
 
 
-	/* get pilot name from gpilotd */
-	/* 1. initialize the gpilotd connection */
-	if (gpilotd_init(&argc,argv)!=0) {
-		run_error_dialog(_("Cannot initialze the GnomePilot Daemon"));
-		g_error(_("Cannot initialze the GnomePilot Daemon"));
-		return -1;
-	}
-    
-	/* 2 connect to gpilotd */
-	if (gpilotd_connect()!=0) {
-		run_error_dialog(_("Cannot connect to the GnomePilot Daemon"));
-		g_error(_("Cannot connect to the GnomePilot Daemon"));
-		return -1;
-	}
-    
+	gpc = GNOME_PILOT_CLIENT(gnome_pilot_client_new());
+	gnome_pilot_client_connect_to_daemon(gpc);
 	pilotId = get_pilot_id_from_gpilotd();
 	if(!pilotId) return -1;
 
 	/* put all code to set things up in here */
-	conduit = gpilotd_conduit_mgmt_new("memo_file_conduit",pilotId);
-
+	conduit = gnome_pilot_conduit_management_new("gpmemo1",GNOME_PILOT_CONDUIT_MGMT_ID);
+	
+	conduit_config = gnome_pilot_conduit_config_new(conduit,pilotId);
 	load_configuration(&origState,pilotId);
-	gpilotd_conduit_mgmt_get_sync_type(conduit,pilotId,&origState->sync_type);
+	gnome_pilot_conduit_config_is_enabled(conduit_config,&origState->sync_type);
 	curState = dupe_configuration(origState);
     
 	pilot_capplet_setup();
