@@ -33,7 +33,7 @@
 GnomePilotConduit *conduit_get_gpilot_conduit (guint32 pilotId);
 void conduit_destroy_gpilot_conduit (GnomePilotConduit *conduit);
 
-#define CONDUIT_VERSION "0.7"
+#define CONDUIT_VERSION "0.81"
 
 static void 
 load_configuration(ConduitCfg **c,guint32 pilotId) 
@@ -192,20 +192,19 @@ generate_name(MemoLocalRecord *local,GnomePilotConduitStandardAbs *abs)
 	gchar *fname;
 	int i = 1;
 	
-	local->filename = (gchar*)g_malloc(FILENAME_MAX);
 	fname = newfilename(local);
-
-	g_snprintf(local->filename,FILENAME_MAX-1,"%s/%s",
-		   category_path(local->local.archived?16:local->category,abs),
-		   fname);
-
+	local->filename = g_strdup_printf("%s/%s",
+					  category_path(local->local.archived?16:local->category,abs),
+					  fname);
+	
 	/* file name already exists, tack on a unique number */
 	if(stat(local->filename,&stbuf) != 0) return;
 
 	for (i = 2; ; ++i) {
-		g_snprintf(local->filename,FILENAME_MAX-1, "%s/%s.%d", 
-			   category_path(local->local.archived?16:local->category,abs),
-			   fname,i);
+		g_free(local->filename);
+		local->filename=g_strdup_printf("%s/%s.%d", 
+						category_path(local->local.archived?16:local->category,abs),
+						fname,i);
 		if (stat(local->filename, &stbuf) != 0)
 			return;
 	}
@@ -218,9 +217,11 @@ static gchar *
 idfile_name(int cnt,GnomePilotConduitStandardAbs *abs) 
 {
 	static gchar filename[FILENAME_MAX];
+	gchar *cpath = NULL;
 
-	if(category_path(cnt,abs))
-		g_snprintf(filename,FILENAME_MAX-1,"%s/.ids",category_path(cnt,abs));
+	cpath = category_path(cnt,abs);
+	if(cpath)
+		g_snprintf(filename,FILENAME_MAX-1,"%s/.ids",cpath);
 	else
 		return NULL;
 
@@ -437,7 +438,7 @@ static void
 create_deleted_record_foreach(gchar *key, LoadInfo *li,GList **records) 
 {
 	MemoLocalRecord *local;
-	local = (MemoLocalRecord*)g_malloc(sizeof(MemoLocalRecord));
+	local = g_new0(MemoLocalRecord,1);
 	local->local.ID = li->id;
 	local->local.secret = li->secret;
 	local->next = NULL;
@@ -598,7 +599,7 @@ load_records(GnomePilotConduitStandardAbs *abs)
 		if((idfile=fopen(filename,"rt"))!=NULL) {
 			while(fgets(entry,1024,idfile)!=NULL) {
 				gchar *key;
-				info = (LoadInfo*)g_malloc(sizeof(LoadInfo));
+				info = g_new0(LoadInfo,1);
 				sscanf(entry,"%lu:%d:%lu;",&info->id,&info->secret,&info->mtime);
 				ptr = strchr(entry,';'); ptr++;
 				
@@ -796,7 +797,7 @@ store_remote (GnomePilotConduitStandardAbs *abs,
   
 	if(tmp==NULL) {
 		/* new record */
-		local = (MemoLocalRecord*)g_malloc(sizeof(MemoLocalRecord));
+		local = g_new0(MemoLocalRecord,1);
 		cd->records = g_list_append(cd->records,local);
 		
 	} else {
@@ -1084,7 +1085,7 @@ conduit_destroy_gpilot_conduit (GnomePilotConduit *conduit)
 	ConduitCfg  *cfg=GET_CONDUIT_CFG(conduit);
 	LOG("destroying memo_file conduit");
 	
-	g_list_foreach(cd->records,(GFunc)free_records_foreach,cd->records);
+	g_list_foreach(cd->records,(GFunc)free_records_foreach,NULL);
 	g_list_free(cd->records);
 	g_free(cd);
 	
