@@ -111,12 +111,14 @@ gnome_pilot_conduit_class_init (GnomePilotConduitClass *klass)
 }
 
 static void
-gnome_pilot_conduit_init (GnomePilotConduit *pilot_conduit)
+gnome_pilot_conduit_init (GnomePilotConduit *conduit)
 {
-	g_return_if_fail (pilot_conduit != NULL);
-	g_return_if_fail (GNOME_IS_PILOT_CONDUIT (pilot_conduit));
+	g_return_if_fail (conduit != NULL);
+	g_return_if_fail (GNOME_IS_PILOT_CONDUIT (conduit));
 
-	pilot_conduit->name = NULL;
+	conduit->name = NULL;
+	conduit->progress_top = 0;
+	conduit->progress_stepping = 1;
 }
 
 static void
@@ -136,22 +138,29 @@ gnome_pilot_conduit_finalize (GtkObject *object)
 
 /* Public Functions */
 void
-gnome_pilot_conduit_construct (GnomePilotConduit *pilot_conduit,
+gnome_pilot_conduit_construct (GnomePilotConduit *conduit,
 			       const gchar *name)
 {
-	g_return_if_fail (pilot_conduit != NULL);
-	g_return_if_fail (GNOME_IS_PILOT_CONDUIT (pilot_conduit));
+	g_return_if_fail (conduit != NULL);
+	g_return_if_fail (GNOME_IS_PILOT_CONDUIT (conduit));
 
-	pilot_conduit->name = g_strdup (name);
+	conduit->name = g_strdup (name);
 }
 
 const gchar *
-gnome_pilot_conduit_get_name (GnomePilotConduit *pilot_conduit)
+gnome_pilot_conduit_get_name (GnomePilotConduit *conduit)
 {
-	g_return_val_if_fail (pilot_conduit != NULL, NULL);
-	g_return_val_if_fail (GNOME_IS_PILOT_CONDUIT (pilot_conduit), NULL);
+	g_return_val_if_fail (conduit != NULL, NULL);
+	g_return_val_if_fail (GNOME_IS_PILOT_CONDUIT (conduit), NULL);
 
-	return (const gchar *) pilot_conduit->name;
+	return (const gchar *) conduit->name;
+}
+
+void
+gnome_pilot_conduit_set_stepping(GnomePilotConduit *conduit,gint stepping) {
+	g_return_if_fail (conduit != NULL);
+	g_return_if_fail (GNOME_IS_PILOT_CONDUIT (conduit));
+	conduit->progress_stepping = stepping;
 }
 
 void
@@ -171,23 +180,50 @@ gnome_real_pilot_conduit_message (GnomePilotConduit *conduit,
 	return;
 }
 
-void gnome_real_pilot_conduit_error(GnomePilotConduit *conduit,
-				    gchar *message,...) {
+void 
+gnome_real_pilot_conduit_error(GnomePilotConduit *conduit,
+			       gchar *message,...) {
 	g_return_if_fail (conduit != NULL);
 	g_return_if_fail (GNOME_IS_PILOT_CONDUIT (conduit));
 	return;
 }
 
+
+/*
+  Stepping defaults to 1.
+
+  If stepping > 0, calc new percentage, if it matches the stepping, emit.
+              = 0, emit
+              < 0, don't emit.
+ */
 void
 gnome_pilot_conduit_progress (GnomePilotConduit *conduit, 
 			      gint total, 
 			      gint current) {
+	gfloat tot_f, cur_f;
+	gint pct;
+
 	g_return_if_fail (conduit != NULL);
 	g_return_if_fail (GNOME_IS_PILOT_CONDUIT (conduit));
 
 	if (current > total) current = total;
-
-	gtk_signal_emit(GTK_OBJECT(conduit),gnome_pilot_conduit_signals[PROGRESS],total,current,NULL);
+	/* if stepping !=0, calc step, otherwise emit the signal */
+	if (conduit->progress_stepping) {
+		tot_f = total;
+		cur_f = current;
+		pct = abs(cur_f/(tot_f/100));
+		
+		if (pct < conduit->progress_stepping) conduit->progress_top = 0;
+		if (pct >= conduit->progress_top + conduit->progress_stepping) {
+			conduit->progress_top = pct;
+			gtk_signal_emit(GTK_OBJECT(conduit),gnome_pilot_conduit_signals[PROGRESS],total,current,NULL);
+		} 
+	} if (conduit->progress_stepping==0) {
+		gtk_signal_emit(GTK_OBJECT(conduit),gnome_pilot_conduit_signals[PROGRESS],total,current,NULL);
+	} else {
+		/* stepping < 0 */
+		return;
+	}
 }
 
 void         
@@ -208,8 +244,9 @@ gnome_pilot_conduit_message (GnomePilotConduit *conduit,
 	va_end(ap);
 }
 
-void gnome_pilot_conduit_error(GnomePilotConduit *conduit,
-			       gchar *message,...) {
+void 
+gnome_pilot_conduit_error(GnomePilotConduit *conduit,
+			  gchar *message,...) {
 	va_list ap;
 	gchar *tmp;
 
@@ -219,7 +256,7 @@ void gnome_pilot_conduit_error(GnomePilotConduit *conduit,
 	va_start(ap,message);
 	tmp = g_strdup_vprintf(message,ap);
 
-	gtk_signal_emit(GTK_OBJECT(conduit),gnome_pilot_conduit_signals[ERROR],message,NULL);
+	gtk_signal_emit(GTK_OBJECT(conduit),gnome_pilot_conduit_signals[ERROR],tmp,NULL);
 
 	g_free(tmp);
 	va_end(ap);
@@ -260,7 +297,7 @@ gnome_pilot_conduit_sync_type_int_to_str(GnomePilotConduitSyncType e)
 	case GnomePilotConduitSyncTypeMergeToPilot:   return "merge_to_pilot";
 	case GnomePilotConduitSyncTypeNotSet:         return "not_set";
 	default: 
-	  g_message("gnome_pilot_conduit_sync_type_int_to_str: invalid sync_type");
+	  g_message("gnome_pilot_conduit_sync_type_int_to_str: invalid sync_type %d",e);
 	  return "not_set";
 	}
 }
