@@ -34,14 +34,19 @@ extern "C" {
 #define GNOME_IS_PILOT_CONDUIT(obj)			(GTK_CHECK_TYPE ((obj), GNOME_TYPE_PILOT_CONDUIT))
 #define GNOME_IS_PILOT_CONDUIT_CLASS(klass)		(GTK_CHECK_CLASS_TYPE ((obj), GNOME_TYPE_PILOT_CONDUIT))
 
-
 typedef struct _GnomePilotConduit         GnomePilotConduit;
 typedef struct _GnomePilotConduitClass    GnomePilotConduitClass;
 
+typedef GnomePilotConduit *(*GnomePilotConduitLoadFunc)(guint32);
+typedef void (*GnomePilotConduitDestroyFunc)(GnomePilotConduit *);
+
 struct _GnomePilotConduit
 {
 	GtkObject parent;
 	gchar *name;
+	/* used to implement the "skipping" progress counter */
+	gint progress_top; 
+	gint progress_stepping;
 };
 struct _GnomePilotConduitClass
 {
@@ -55,16 +60,18 @@ struct _GnomePilotConduitClass
 
 
 GtkType      gnome_pilot_conduit_get_type 	(void);
-void         gnome_pilot_conduit_construct      (GnomePilotConduit *pilot_conduit,
-						 const gchar *name);
-const gchar* gnome_pilot_conduit_get_name       (GnomePilotConduit *pilot_conduit); 
+void         gnome_pilot_conduit_construct (GnomePilotConduit *conduit,
+					    const gchar *name);
+void         gnome_pilot_conduit_set_stepping (GnomePilotConduit *conduit,
+					       gint stepping);
+const gchar* gnome_pilot_conduit_get_name       (GnomePilotConduit *conduit); 
 
-void         gnome_pilot_conduit_progress       (GnomePilotConduit *pilot_conduit, 
+void         gnome_pilot_conduit_progress       (GnomePilotConduit *conduit, 
 						 gint total, 
 						 gint current);
-void         gnome_pilot_conduit_message        (GnomePilotConduit *pilot_conduit,
+void         gnome_pilot_conduit_message        (GnomePilotConduit *conduit,
 						 gchar *message,...);
-void         gnome_pilot_conduit_error          (GnomePilotConduit *pilot_conduit,
+void         gnome_pilot_conduit_error          (GnomePilotConduit *conduit,
 						 gchar *message,...);
 
 typedef enum {
