@@ -54,6 +54,10 @@ extern void gpilotd_conduit_error(const gchar *id,
 gint gpilotd_init(int *argc,char *argv[]);
 gint gpilotd_connect(void);
 void gpilotd_shutdown(void);
+gint gpilotd_pause(void);
+gint gpilotd_unpause(void);
+pid_t gpilotd_get_pid(void);  /* returns -1 if pid is unavailable */
+gint gpilotd_restart(void);
 
 gint gpilotd_monitor_on(gchar *pilot_id);
 gint gpilotd_monitor_off(gchar *pilot_id);
@@ -97,7 +101,6 @@ gint gpilotd_conduit(gchar *pilot,
    */
 
 int gpilotd_get_users(gchar***);
-int gpilotd_get_conduits(gchar***);
 int gpilotd_get_cradles(gchar***);
 int gpilotd_get_pilot_names(gchar***);
 int gpilotd_get_pilot_ids(gint**);
