@@ -21,6 +21,7 @@
 #include <pi-dlp.h>
 #include <pi-version.h>
 #include <sys/wait.h>
+#include <sys/stat.h>
 #include <pwd.h>
 
 #include "orbit_daemon_glue.h"
@@ -184,6 +185,7 @@ do_cradle_events(int pfd,
 			g_snprintf(pu->username,127,"%s",req->parameters.set_userinfo.user_id);
 			pu->userID = req->parameters.set_userinfo.pilot_id;
 			dlp_WriteUserInfo(pfd,pu);
+			if (req->parameters.set_userinfo.continue_sync) ret = FALSE;
 			orbed_notify_completion(&req);
 			break;
 		case GREQ_GET_USERINFO:
@@ -200,11 +202,6 @@ do_cradle_events(int pfd,
 			   orbed_notify_completion(&req);
 			*/
 			break;
-		case GREQ_REVIVE:
-			/* continue sync after this */
-			ret = FALSE;
-			g_assert("not implemented");
-			break;
 		default:
 			g_warning("%s:%d: *** type = %d",__FILE__,__LINE__,req->type);
 			g_assert_not_reached();
@@ -246,7 +243,8 @@ do_sync(int pfd,
 
 	pilot_name = pilot_name_from_id(pu->userID,context);
 
-	gpilot_load_conduits(pilot,
+	gpilot_load_conduits(context,
+			     pilot,
 			     &conduit_list, 
 			     &backup_conduit_list,
 			     &file_conduit_list);
@@ -261,7 +259,7 @@ do_sync(int pfd,
 	/* Set a log entry in the pilot */
 	{
 		gchar hostname[64];
-		gpilot_add_log_entry(pfd,"GnomePilot v.%s\n",VERSION);
+		gpilot_add_log_entry(pfd,"gnome-pilot v.%s\n",VERSION);
 		if (gethostname(hostname,63)==0)
 			gpilot_add_log_entry(pfd,_("On host %s\n"),hostname);
 		else
