@@ -19,7 +19,6 @@
 #include <libgpilotdCM/gnome-pilot-conduit-management.h>
 #include <libgpilotdCM/gnome-pilot-conduit-config.h>
 
-#define PROGRESS_STEPPING 5
 #define GPCM_LABEL "conduit_mgmt"
 #define GPCC_LABEL "conduit_cfg"
 
@@ -170,6 +169,7 @@ conduit_error_callback(GnomePilotConduit *conduit,
    NOTE: Not reentrant! lock when set, unlock when unset.
    could potientially be reentrant since the pilot-name
    would be unique even for multicradle sync
+   FIXME: yech, actually this is quite ugly.
 */
 static void 
 set_callbacks(gboolean set,GnomePilotConduit *conduit, gchar *pilot_name) 
@@ -191,8 +191,7 @@ set_callbacks(gboolean set,GnomePilotConduit *conduit, gchar *pilot_name)
 		
 		message_h = gtk_signal_connect(GTK_OBJECT(conduit),"message",
 					       (GtkSignalFunc)conduit_message_callback,
-					       pilot_name);
-		gnome_pilot_conduit_set_stepping(conduit,PROGRESS_STEPPING);
+					       pilot_name);	       
 	} else {
 		if (progress_h == 0) g_warning("Internal inconsistency, see %s:%d",
 					       __FILE__,__LINE__);
@@ -245,7 +244,7 @@ iterate_dbs (gint pfd,
 
 	while(1) {
 		if(dlp_OpenConduit(pfd) < 0) {
-			g_error("Unable to open conduit!");
+			g_warning("Unable to open conduit!");
 			error = -1;
 			break;
 		}
@@ -542,7 +541,8 @@ unload_foreach(GnomePilotConduit *conduit,
 
 
 void
-gpilot_load_conduits (GPilotPilot *pilot,
+gpilot_load_conduits (GPilotContext *context,
+		      GPilotPilot *pilot,
 		      GList **clist,
 		      GList **blist,
 		      GList **flist)
@@ -587,6 +587,8 @@ gpilot_load_conduits (GPilotPilot *pilot,
 			continue;
 		}
 
+		gnome_pilot_conduit_set_stepping (conduit, context->progress_stepping);
+
 		gtk_object_set_data (GTK_OBJECT (conduit), GPCM_LABEL, manager);
 		gtk_object_set_data (GTK_OBJECT (conduit), GPCC_LABEL, conduit_config);
 
