@@ -69,7 +69,16 @@ void gpilot_add_log_entry(int pilot_socket,
 void gpilot_remove_first_sync_settings(guint32 pilot_id,
 				       gchar *config_name);
 
-void gpilot_load_conduits(GPilotPilot *, GList **, GList **, GList **);
+/* Given a context, a pilot, loads the conduits into three lists,
+   The conduits, the backup conduits and the file install conduits.
+   The latter two are typically only 1 element a list */
+void gpilot_load_conduits(GPilotContext *context,
+			  GPilotPilot *, 
+			  GList **, 
+			  GList **, 
+			  GList **);
+
+/* Deinstantiate a list of conduits */
 void gpilot_unload_conduits(GList *l);
 
 #endif /* _INTERNAL_MANAGER_H_ */
