@@ -343,61 +343,6 @@ gpilotd_corba_request_restore(GNOME_Pilot_Daemon obj,
 	return gpc_queue_store_request(req);
 }
 
-static CORBA_unsigned_long
-gpilotd_corba_request_revive(GNOME_Pilot_Daemon obj,
-			     const GNOME_Pilot_Client cb,
-			     const CORBA_char *cradle,
-			     const GNOME_Pilot_PilotUser *user,
-			     const CORBA_char *_directory,
-			     const GNOME_Pilot_Survival survival,
-			     const CORBA_unsigned_long timeout,
-			     CORBA_Environment *ev)
-{
-	GPilotRequest req;
-	gchar *directory;
-	struct stat statbuf;
-	char *client_id;
-	
-	GET_AND_CHECK_CLIENT_ID(client_id,cb,0);
-
-	directory = g_strdup(_directory);
-	/* FIXME: should be a generic / remover */
-	if (directory[strlen(directory)-1]=='/')
-		directory[strlen(directory)-1]=0;
-	LOG("corba: request_revive(cradle=%s, directory=%s,survival=%d,timeout=%d)",
-	    cradle,
-	    directory,
-	    survival,
-	    timeout);
-
-	req.type = GREQ_REVIVE;
-
-	if(stat(directory,&statbuf)==-1) {
-		g_free(client_id);
-		g_free(directory);
-		gpthrow(MissingFile,0);
-	}
-	if(S_ISDIR(statbuf.st_mode) && access(directory,R_OK)!=0) {
-		g_free(client_id);
-		g_free(directory);
-		g_message("or here access=%d, S_ISDIR=%d",access(directory,R_OK),S_ISDIR(statbuf.st_mode));
-		gpthrow(MissingFile,0);
-	}
-	req.timeout = survival==GNOME_Pilot_PERSISTENT?0:timeout;
-	req.cradle = NULL;
-	req.client_id = g_strdup(client_id);
-
-	req.parameters.revive.directory = g_strdup(directory);
-	req.parameters.revive.password = NULL;
-	req.parameters.revive.user_id = g_strdup(user->username);
-	req.parameters.revive.pilot_id = user->userID;
-
-	g_free(directory);
-	g_free(client_id);
-
-	return gpc_queue_store_request(req);
-}
-
 static CORBA_unsigned_long
 gpilotd_corba_request_conduit(GNOME_Pilot_Daemon _obj, 
 			      const GNOME_Pilot_Client cb,
@@ -1337,7 +1282,6 @@ POA_GNOME_Pilot_Daemon__epv daemon_epv = {
 	(gpointer)&gpilotd_corba_pause,
 	(gpointer)&gpilotd_corba_request_install,
 	(gpointer)&gpilotd_corba_request_restore,
-	(gpointer)&gpilotd_corba_request_revive,
 	(gpointer)&gpilotd_corba_request_conduit,
 	(gpointer)&gpilotd_corba_request_remove,
 	(gpointer)&gpilotd_corba_get_system_info,
