@@ -29,7 +29,6 @@ typedef enum {
   GREQ_GET_USERINFO,
   GREQ_SET_USERINFO,
   GREQ_NEW_USERINFO,
-  GREQ_REVIVE,
 
   GREQ_INVALID=-1,
 } GPilotRequestType;
@@ -51,12 +50,6 @@ typedef struct GPilotRequest {
 		struct {
 			gchar *directory;
 		} restore;
-		struct {
-			gchar *password;
-			gchar *user_id;
-			guint32 pilot_id;
-			gchar *directory;
-		} revive;
 		struct {
 			gchar *name;
 			GnomePilotConduitSyncType how;
@@ -64,6 +57,7 @@ typedef struct GPilotRequest {
 		struct {
 			gchar *password;
 			gchar *user_id;
+			gboolean continue_sync;
 			guint32 pilot_id;
 		} set_userinfo;
 		struct {
