@@ -156,13 +156,19 @@ revive(char *rest)
 	g_message("Reviving %d to %s from %s",arg_id,arg_cradle,arg_restore);
 	user.userID = arg_id;
 	user.username = CORBA_string_dup(arg_username);
-	err = gnome_pilot_client_revive(gpc,
-					arg_cradle,
-					&user,
-					arg_restore,
-					GNOME_Pilot_PERSISTENT,
-					0,
-					&outstanding_request);
+	err = gnome_pilot_client_set_user_info(gpc,
+					       arg_cradle,
+					       user,
+					       FALSE,
+					       GNOME_Pilot_PERSISTENT,
+					       0,
+					       &outstanding_request);
+	err = gnome_pilot_client_restore(gpc,
+					 arg_pilot,
+					 arg_restore,
+					 GNOME_Pilot_PERSISTENT,
+					 0,
+					 &outstanding_request);
 	print_err(err);
 	if (err==GPILOTD_OK)
 		the_loop();
@@ -198,7 +204,7 @@ set_user()
 	gboolean abort = FALSE;
 
 	if (arg_id==0) {
-		g_warning("Please set a pilotid using --id");
+		g_warning("Please set a pilotid using --pilotid");
 		abort = TRUE;
 	}
 	if (arg_username==NULL) {
@@ -217,6 +223,7 @@ set_user()
 		err = gnome_pilot_client_set_user_info(gpc,
 						       arg_cradle,
 						       user,
+						       FALSE,
 						       GNOME_Pilot_PERSISTENT,
 						       0,
 						       &outstanding_request);
